@@ -3,10 +3,12 @@
 # Distributed under the terms of the Modified BSD License.
 import itertools
 import json
+import os
 import re
 import warnings
 from fnmatch import fnmatch
 
+from jupyter_client.utils import run_sync
 from jupyter_core.utils import ensure_async
 from jupyter_events import EventLogger
 from nbformat import ValidationError, sign
@@ -65,10 +67,40 @@ class ContentsManager(LoggingConfigurable):
 
     root_dir = Unicode("/", config=True)
 
+    preferred_dir = Unicode(
+        "",
+        config=True,
+        help=_i18n(
+            "Preferred starting directory to use for notebooks. This is an API path (`/` separated, relative to root dir)"
+        ),
+    )
+
+    @validate("preferred_dir")
+    def _validate_preferred_dir(self, proposal):
+        value = proposal["value"].strip("/")
+        try:
+            import inspect
+
+            if inspect.iscoroutinefunction(self.dir_exists):
+                dir_exists = run_sync(self.dir_exists)(value)
+            else:
+                dir_exists = self.dir_exists(value)
+        except HTTPError as e:
+            raise TraitError(e.log_message) from e
+        if not dir_exists:
+            raise TraitError(_i18n("Preferred directory not found: %r") % value)
+        try:
+            if value != self.parent.preferred_dir:
+                self.parent.preferred_dir = os.path.join(self.root_dir, *value.split("/"))
+        except (AttributeError, TraitError):
+            pass
+        return value
+
     allow_hidden = Bool(False, config=True, help="Allow access to hidden files")
 
     notary = Instance(sign.NotebookNotary)
 
+    @default("notary")
     def _notary_default(self):
         return sign.NotebookNotary(parent=self)
 
@@ -338,7 +370,7 @@ class ContentsManager(LoggingConfigurable):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path to check
 
         Returns
@@ -353,7 +385,7 @@ class ContentsManager(LoggingConfigurable):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path to check. This is an API path (`/` separated,
             relative to root dir).
 
@@ -374,7 +406,7 @@ class ContentsManager(LoggingConfigurable):
 
         Parameters
         ----------
-        path : string
+        path : str
             The API path of a file to check for.
 
         Returns
@@ -391,7 +423,7 @@ class ContentsManager(LoggingConfigurable):
 
         Parameters
         ----------
-        path : string
+        path : str
             The API path of a file or directory to check for.
 
         Returns
@@ -648,7 +680,7 @@ class ContentsManager(LoggingConfigurable):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path of a notebook
         """
         model = self.get(path)
@@ -666,7 +698,7 @@ class ContentsManager(LoggingConfigurable):
         ----------
         nb : dict
             The notebook dict
-        path : string
+        path : str
             The notebook's path (for logging)
         """
         if self.notary.check_cells(nb):
@@ -683,7 +715,7 @@ class ContentsManager(LoggingConfigurable):
         ----------
         nb : dict
             The notebook object (in current nbformat)
-        path : string
+        path : str
             The notebook's path (for logging)
         """
         trusted = self.notary.check_signature(nb)
@@ -743,7 +775,7 @@ class AsyncContentsManager(ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path to check
 
         Returns
@@ -758,7 +790,7 @@ class AsyncContentsManager(ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path to check. This is an API path (`/` separated,
             relative to root dir).
 
@@ -779,7 +811,7 @@ class AsyncContentsManager(ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The API path of a file to check for.
 
         Returns
@@ -796,7 +828,7 @@ class AsyncContentsManager(ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The API path of a file or directory to check for.
 
         Returns
@@ -1017,7 +1049,7 @@ class AsyncContentsManager(ContentsManager):
 
         Parameters
         ----------
-        path : string
+        path : str
             The path of a notebook
         """
         model = await self.get(path)
