@@ -8,6 +8,7 @@ import socket
 import sys
 import warnings
 from contextlib import contextmanager
+from typing import NewType
 from urllib.parse import (
     SplitResult,
     quote,
@@ -17,14 +18,16 @@ from urllib.parse import (
     urlsplit,
     urlunsplit,
 )
-from urllib.request import pathname2url  # noqa
+from urllib.request import pathname2url  # noqa: F401
 
-from _frozen_importlib_external import _NamespacePath
+from _frozen_importlib_external import _NamespacePath  # type:ignore
 from jupyter_core.utils import ensure_async
 from packaging.version import Version
 from tornado.httpclient import AsyncHTTPClient, HTTPClient, HTTPRequest
 from tornado.netutil import Resolver
 
+ApiPath = NewType("ApiPath", str)
+
 
 def url_path_join(*pieces):
     """Join components of url into a relative url
@@ -97,8 +100,10 @@ def samefile_simple(path, other_path):
 
     Parameters
     ----------
-    path : String representing a path to a file
-    other_path : String representing a path to another file
+    path : str
+        representing a path to a file
+    other_path : str
+        representing a path to another file
 
     Returns
     -------
@@ -109,19 +114,19 @@ def samefile_simple(path, other_path):
     return path.lower() == other_path.lower() and path_stat == other_path_stat
 
 
-def to_os_path(path, root=""):
+def to_os_path(path: ApiPath, root: str = "") -> str:
     """Convert an API path to a filesystem path
 
     If given, root will be prepended to the path.
     root must be a filesystem path already.
     """
-    parts = path.strip("/").split("/")
+    parts = str(path).strip("/").split("/")
     parts = [p for p in parts if p != ""]  # remove duplicate splits
-    path = os.path.join(root, *parts)
-    return os.path.normpath(path)
+    path_ = os.path.join(root, *parts)
+    return os.path.normpath(path_)
 
 
-def to_api_path(os_path, root=""):
+def to_api_path(os_path: str, root: str = "") -> ApiPath:
     """Convert a filesystem path to an API path
 
     If given, root will be removed from the path.
@@ -132,7 +137,7 @@ def to_api_path(os_path, root=""):
     parts = os_path.strip(os.path.sep).split(os.path.sep)
     parts = [p for p in parts if p != ""]  # remove duplicate splits
     path = "/".join(parts)
-    return path
+    return ApiPath(path)
 
 
 def check_version(v, check):
@@ -323,11 +328,16 @@ def filefind(filename, path_dirs=None):
     the full, absolute path of the first occurence of the file.  If no set of
     path dirs is given, the filename is tested as is, after running through
     :func:`expandvars` and :func:`expanduser`.  Thus a simple call::
+
         filefind('myfile.txt')
+
     will find the file in the current working dir, but::
+
         filefind('~/myfile.txt')
+
     Will find the file in the users home directory.  This function does not
     automatically try any paths, such as the cwd or the user's home directory.
+
     Parameters
     ----------
     filename : str
@@ -338,6 +348,7 @@ def filefind(filename, path_dirs=None):
         put into a sequence and the searched.  If a sequence, walk through
         each element and join with ``filename``, calling :func:`expandvars`
         and :func:`expanduser` before testing for existence.
+
     Returns
     -------
     Raises :exc:`IOError` or returns absolute path to file.
@@ -367,6 +378,7 @@ def filefind(filename, path_dirs=None):
 
 def expand_path(s):
     """Expand $VARS and ~names in a string, like a shell
+
     :Examples:
        In [2]: os.environ['FOO']='test'
        In [3]: expand_path('variable FOO is $FOO')
@@ -391,7 +403,7 @@ def import_item(name):
     executing the code ``from foo import bar``.
     Parameters
     ----------
-    name : string
+    name : str
       The fully qualified name of the module/package being imported.
     Returns
     -------
